import unittest
import onkopus
"""

class TestCLIAnnotation(unittest.TestCase):


    def test_cli_annotation(self):
        infile = "./test_files/input.csv"
        outfile = infile + ".anno.csv"
        bframe = onkopus.read_file(infile)
        bframe.data = onkopus.annotate_variant_data(bframe.data)
        onkopus.write_file(outfile,bframe)

"""